#! /bin/sh

if [ ! $# -eq 1 ]; then
	echo "usage installImage.sh <rootfs.tar>"
	exit
fi

if [ $(whoami) != "root" ]; then
	echo "must be called as root, please use 'sudo ..'"
	exit
fi 

#########################################
# begin script section
#########################################

ROOTFS=$1

DEVICE=$(mount | grep " / " | cut -d' ' -f1 | sed 's/[45]//g')
USED_PART=$(mount | grep " / " | cut -d' ' -f1 | sed 's/[a-z\/]//g')

if [ $USED_PART -eq 3 ]; then
	SYS_ACT="RECOVER"
	SYS_NEW="SYS1"
	SYS_NR=1
	PARTITION=${DEVICE}4
elif [ $USED_PART -eq 4 ]; then
	SYS_ACT="SYS1"
	SYS_NEW="SYS2"
	SYS_NR=2
	PARTITION=${DEVICE}5
elif [ $USED_PART -eq 5 ]; then
	SYS_ACT="SYS2"
	SYS_NEW="SYS1"
	SYS_NR=1
	PARTITION=${DEVICE}4
fi

read -p "Confirm to install \"${PARTITION}\" [y/N]: " CONFIRMATION

case "$CONFIRMATION" in
	y) ;;
	*) exit 0;;
esac

#########################################
# format the partitions
#########################################

FSTYPE="ext4"
mke2fs -q -F -t ${FSTYPE} -L SYS${SYS_NR} ${PARTITION}

#########################################
# mount partitions
#########################################

umount -q /mnt
mount ${PARTITION} /mnt

#########################################
# setup SYS partition
#########################################

sudo tar -xj --totals -f ${ROOTFS} -C /mnt
cp /mnt/boot/bzImage /boot/efi/bzImage-${SYS_NEW}

# restore hostname
if [ -f /etc/hostname ] ; then
	cp /etc/hostname /mnt/etc
fi

# restore ifcfg-eth0
if [ -f /etc/network/ifcfg-eth0 ] ; then
	cp /etc/network/ifcfg-eth0 /mnt/etc/network
fi

# restore timezone
if [ -f /etc/timezone ] ; then
	logecho "restore timezone $(${SYS_NEW}/etc/timezone)"
	TZ=$(cat /etc/timezone)
	rm -f /mnt/etc/localtime
	ln -s /mnt/usr/share/zoneinfo/${TZ} /mnt/etc/localtime
	cp /etc/timezone /mnt/etc
fi

#########################################
# setup boot partition
#########################################

grub-editenv /boot/efi/EFI/BOOT/grubenv set DEFAULT=${SYS_NR}
grub-editenv /boot/efi/EFI/BOOT/grubenv set BC=0
grub-editenv /boot/efi/EFI/BOOT/grubenv set SWAP=1

#########################################
# unmount partitions
#########################################

echo "umounting ..."
umount /mnt

#########################################
# swap to new installation
#########################################

read -p "Confirm to swap from \"${SYS_ACT}\" to \"${SYS_NEW}\" [Y/n]: " CONFIRMATION

case "$CONFIRMATION" in
	"") ;;
	y) ;;
	*) exit 0;;
esac

reboot
