# !/bin/bash
#
# Commonly used functions for starter and daemon
# Copyright (c) RAYLASE GmbH
#

# Device node for MMC-Device
DISKDEVNAME="sda"
DISKDEVICE="/dev/${DISKDEVNAME}"

# Temporary directory in ramdisk
TEMPDIR="/tmp"

# Partition numbers for partitions
EFI_DEVID=1
#SWAP_DEVID=2
IMG0_DEVID=3
IMG1_DEVID=4
IMG2_DEVID=5
UPD_DEVID=6
HOME_DEVID=7

# Mount points
UPD_DIR="/var/updates"

LOG_DIR="/home/sfc/Logs"
LOG_FILE="${LOG_DIR}/sfc.update.log"

# Number of currently booted image
export BOOTED_IMAGE='0'
export _IMAGE='0'

logecho_init() {
	logecho "--------- Update Log Started --------"
}

logecho() {
	echo "$(date '+%Y-%m-%dT%H:%M:%S.%3N') $*" >>"${LOG_FILE}"
}

# Exit on fatal errors
fatal() {
	logecho "************ Fatal error ************"
	logecho $*
	logecho "******** Terminating program ********"
	exit 1
}

# Check which image is running currently
check_booted_image() {
	local BOOTEDPARTNUM=$(mount | grep " / " | cut -d' ' -f1 | sed -e 's/\/...\/...//')
	if [ $? == 0 ] ; then
		BOOTED_IMAGE=0
		case "${BOOTEDPARTNUM}" in 
			"${IMG0_DEVID}" )
				BOOTED_IMAGE=0
				;;
			"${IMG1_DEVID}" )
				BOOTED_IMAGE=1
				;;
			"${IMG2_DEVID}" )
				BOOTED_IMAGE=2
				;;
		esac
		
		local BOOTEDPART=$(mount | grep " / " | cut -d' ' -f1)
		local BOOTEDPARTLABEL=$(ls -l /dev/disk/by-label | grep "${DISKDEVNAME}${BOOTEDPARTNUM}" | awk '{print $9}')

		logecho "Booted from Image ${BOOTED_IMAGE}, label ${BOOTEDPARTLABEL}, partition ${BOOTEDPART}"
		logecho "SFC Version: $(tr '\n' ' ' < /sfc-image-version )"
	else
		fatal "Not able to detect boot image number"
	fi
}

restore_etc() {
	# restore hostname
	if [ -f /etc/hostname ] ; then
		logecho "restore hostname $(${MOUNT_DIR}/etc/hostname)"
		cp /etc/hostname ${MOUNT_DIR}/etc
	fi
	
	# restore ifcfg-eth0
	if [ -f /etc/network/ifcfg-eth0 ] ; then
		logecho "restore eth0 $(${MOUNT_DIR}/etc/network/ifcfg-eth0)"
		cp /etc/network/ifcfg-eth0 ${MOUNT_DIR}/etc/network
	fi
	
	# restore timezone
	if [ -f /etc/timezone ] ; then
		logecho "restore timezone $(${MOUNT_DIR}/etc/timezone)"
		TZ=$(cat /etc/timezone)
		rm -f ${MOUNT_DIR}/etc/localtime
		ln -s /usr/share/zoneinfo/${TZ} ${MOUNT_DIR}/etc/localtime
		cp /etc/timezone ${MOUNT_DIR}/etc
	fi
}

send_signal_to_firmware() {	
	sfcpid=$(pgrep -f "dotnetDaemon sfc_app")

	if [ ! -z $sfcpid ]
	then
		# Send SIGUSR1 to sfc_app
		pkill -SIGUSR1 -P ${sfcpid}
	fi
}

# Set new boot device
write_grub_boot_device() {
	logecho "write to GRUB new boot entry = $1"
	grub-editenv /boot/efi/EFI/BOOT/grubenv set DEFAULT=$1
	grub-editenv /boot/efi/EFI/BOOT/grubenv set BC=0
	grub-editenv /boot/efi/EFI/BOOT/grubenv set SWAP=1
}

rotate_logfile() {
	# quasi rotate the update log (if necessary), keeping a max of 10 old logs
	# must a copy because of update RECOVER partion make no reboot, webserver reads the pid
	cp "${LOG_FILE}" "${LOG_FILE%%.log}.$(date +%Y-%m-%d.%H%M%S).log"
	ls -1tr "${LOG_FILE%%.log}"*".log" | head -n -10 | xargs -d '\n' rm -f
	sync
}
